@@ -9,16 +9,22 @@ nodes again.  This does not cause nodes to be matched against the policy until
 the next time they check in.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Enable a policy:
 
     {"name": "example"}
   EOT
 
+  example cli: <<-EOT
+Enable a policy:
+
+    razor enable-policy --name example
+  EOT
+
 
   authz '%{name}'
   attr  'name', type: String, required: true, references: Razor::Data::Policy,
-                help: _('The name of the policy to enable')
+                help: _('The name of the policy to enable.')
 
   def run(request, data)
     policy = Razor::Data::Policy[:name => data['name']]
